==> haskell-cheapskate-0.1.1-104-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1
id: cheapskate-0.1.1-LLYblZVkr0nLunROL1395P
key: cheapskate-0.1.1-LLYblZVkr0nLunROL1395P
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: 436ffdbb7a67748f4bf1d551d07d029c
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cheapskate-0.1.1
hs-libraries: HScheapskate-0.1.1-LLYblZVkr0nLunROL1395P
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2 text-1.2.3.0
    blaze-html-0.9.1.1-ImJwSrLxU02EzwI2h3NYFG
    xss-sanitize-0.3.5.7-4ZVt7C4pvgT6BbIpeRIkjW
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
    uniplate-1.6.12-JvWYUgm31hDD4CbULPBW8K deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             blaze-html-0.9.1.1-ImJwSrLxU02EzwI2h3NYFG=c53bb3bf02513bb30eb5ce3eb528e263
             xss-sanitize-0.3.5.7-4ZVt7C4pvgT6BbIpeRIkjW=0d00a892b2827ba5b03fc4e638ca7f58
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             uniplate-1.6.12-JvWYUgm31hDD4CbULPBW8K=1aab77f3cb6b8e26f474ae997f8b565e
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1-111-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1
id: cheapskate-0.1.1-EPZ5tUs4wUmHckX0Gq3Yst
key: cheapskate-0.1.1-EPZ5tUs4wUmHckX0Gq3Yst
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: bc40854829762f7d1cbdc7492c374ae5
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cheapskate-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cheapskate-0.1.1
hs-libraries: HScheapskate-0.1.1-EPZ5tUs4wUmHckX0Gq3Yst
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2 text-1.2.3.0
    blaze-html-0.9.1.1-ImJwSrLxU02EzwI2h3NYFG
    xss-sanitize-0.3.6-AHgwoxUMOVtDCqd38aJepM
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
    uniplate-1.6.12-JvWYUgm31hDD4CbULPBW8K deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             blaze-html-0.9.1.1-ImJwSrLxU02EzwI2h3NYFG=c53bb3bf02513bb30eb5ce3eb528e263
             xss-sanitize-0.3.6-AHgwoxUMOVtDCqd38aJepM=74b8ef1da8c7c835e640c10f46b3fe17
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             uniplate-1.6.12-JvWYUgm31hDD4CbULPBW8K=1aab77f3cb6b8e26f474ae997f8b565e
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
